#[repr(simd)]pub struct HvxVectorPred([i32; 32]);🔬This is a nightly-only experimental API. (
stdarch_hexagon #151523)Available on
target_arch=hexagon only.Expand description
HVX vector predicate type (1024 bits / 128 bytes)
This type represents a predicate vector used for conditional operations. Each bit corresponds to a lane in the vector.
Tuple Fields
0: [i32; 32]🔬This is a nightly-only experimental API. (
stdarch_hexagon #151523)Implementations
Sourceimpl HvxVectorPred
impl HvxVectorPred
Sourcefn splat(value: i32) -> HvxVectorPred
🔬This is a nightly-only experimental API. (stdarch_hexagon #151523)
fn splat(value: i32) -> HvxVectorPred
stdarch_hexagon #151523)Put the same value in every lane.
Sourceconst fn as_array(&self) -> &[i32; 32]
🔬This is a nightly-only experimental API. (stdarch_hexagon #151523)
const fn as_array(&self) -> &[i32; 32]
stdarch_hexagon #151523)Returns an array reference containing the entire SIMD vector.
Sourcefn as_mut_array(&mut self) -> &mut [i32; 32]
🔬This is a nightly-only experimental API. (stdarch_hexagon #151523)
fn as_mut_array(&mut self) -> &mut [i32; 32]
stdarch_hexagon #151523)Returns a mutable array reference containing the entire SIMD vector.